<?php

if (!defined('_PS_VERSION_')) {
    exit;
}

class OnlyARule extends Module
{
    public function __construct()
    {
        $this->name = 'onlyarule';
        $this->tab = 'front_office_features';
        $this->version = '1.0.0';
        $this->author = 'John Wong';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = array('min' => '1.7.1.0', 'max' => _PS_VERSION_);
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Only a Rule');
        $this->description = $this->l('Select only one cart rule.');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
    }

    public function install()
    {
        if (Shop::isFeatureActive()) {
            Shop::setContext(Shop::CONTEXT_ALL);
        }
        
        if (!parent::install() ||
            !Configuration::updateValue('ONLY_A_RULE', '1') ||
            !Configuration::updateValue('ONLY_A_RULE_IDS', '') 
        ) {
            return false;
        }

        return true;
    }
    
 
    public function uninstall()
    {
        if (!parent::uninstall() ||
            !Configuration::deleteByName('ONLY_A_RULE') ||
            !Configuration::deleteByName('ONLY_A_RULE_IDS') 
        ) {
            return false;
        }
        
        return true;
    }    

    public function getContent()
    {
        $output = null;

        if (Tools::isSubmit('submit'.$this->name)) {
            $opcion = strval(Tools::getValue('ONLY_A_RULE'));
            $ids = strval(Tools::getValue('ONLY_A_RULE_IDS'));
            if (
                 !$ids
                || empty($ids)
                || !Validate::isGenericName($ids)
            ) {
                $output .= $this->displayError($this->l('Invalid Configuration value '.$opcion));
            } else {
                Configuration::updateValue('ONLY_A_RULE', $opcion);
                Configuration::updateValue('ONLY_A_RULE_IDS', $ids);
                $output .= $this->displayConfirmation($this->l('Settings updated'));
            }
        }

        return $output.$this->displayForm();
    }

    public function displayForm()
    {
        // Get default language
        $defaultLang = (int)Configuration::get('PS_LANG_DEFAULT');

        // Init Fields form array
        $fieldsForm[0]['form'] = [
            'legend' => [
                'title' => $this->l('Settings'),
            ],
            'input' => [
                [
                    'type' => 'text',
                    'label' => $this->l('Ids Discount:'),
                    'name' => 'ONLY_A_RULE_IDS',
                    'size' => 40,
                    'required' => true,
                    'hint' => 'Ids de los descuentos a condicionar'
                ],
                [
                    'type' => 'switch',
                    'label' => $this->l('Exclude Cart Rules with discount:'),
                    'name' => 'ONLY_A_RULE',
                    'required' => true,
                    'values' => array(
                        array(
                            'id' => 'ONLY_A_RULE.on',
                            'value' => 1,
                            'label' => $this->l('Enabled')
                        ),
                        array(
                            'id' => 'ONLY_A_RULE.off',
                            'value' => 0,
                            'label' => $this->l('Disabled')
                        )
                    )
                ]                                               
            ],
            'submit' => [
                'title' => $this->l('Save'),
                'class' => 'btn btn-default pull-right'
            ]
        ];

        $helper = new HelperForm();

        // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;

        // Language
        $helper->default_form_language = $defaultLang;
        $helper->allow_employee_form_lang = $defaultLang;

        // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = true;        // false -> remove toolbar
        $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
        $helper->submit_action = 'submit'.$this->name;
        $helper->toolbar_btn = [
            'save' => [
                'desc' => $this->l('Save'),
                'href' => AdminController::$currentIndex.'&configure='.$this->name.'&save'.$this->name.
                '&token='.Tools::getAdminTokenLite('AdminModules'),
            ],
            'back' => [
                'href' => AdminController::$currentIndex.'&token='.Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->l('Back to list')
            ]
        ];

        // Load current value
        $helper->fields_value['ONLY_A_RULE'] = Configuration::get('ONLY_A_RULE');
        $helper->fields_value['ONLY_A_RULE_IDS'] = Configuration::get('ONLY_A_RULE_IDS');
        return $helper->generateForm($fieldsForm);
    }

    public function checkImport() {
        $cart_rules = Cart::getCartRules(CartRule::FILTER_ACTION_ALL, false);
        foreach ($cart_rules as &$cart_rule) {
            return $cart_rule['value_real'];
        }
    }

}
